!
! Read data to a netcdf file
!
!
! Compile with something like:
!
! gfortran -o read_netcdf read_netcdf.f90 -I.../netcdf/include -L.../netcdf/lib -lnetcdff -lnetcdf
!
! or 
! gfortran -o read_netcdf read_netcdf.f90 $(nc-config --fflags --flibs)
!
! Execute:
!
! ./read_netcdf
!

program read_netcdf
 use netcdf
 implicit none

 integer :: ncid, status, dimids(2), varid
 integer :: i,j
 real :: temp(6,4), valid_range(2)
 character(64) :: units

! open netcdf file example.nc in read-only

 status = nf90_open('example.nc',nf90_nowrite,ncid)
 call check_error(status)

! find the identifier for the variable 'temp'

 status = nf90_inq_varid(ncid, 'temp', varid)
 call check_error(status)

! retrieve the netcdf variable temp
! the variable temp must have the same size than in the NetCDF file

 status = nf90_get_var(ncid, varid, temp)
 call check_error(status)

! retrieve the attribute units of variable temp

 status = nf90_get_att(ncid, varid, 'units', units)
 call check_error(status)

! retrieve the attribute valid_range of variable temp

 status = nf90_get_att(ncid, varid, 'valid_range', valid_range)
 call check_error(status)

! close file

 status = nf90_close(ncid)
 call check_error(status)

 write(6,*) 'Units: ',units
 write(6,*) 'Valid_range: ',valid_range
 write(6,*) 'Temp: '

 do j=1,4
   write(6,*) (temp(i,j),i=1,6)
 end do


contains

 subroutine check_error(status)
  integer, intent ( in) :: status

  if(status /= nf90_noerr) then
    write(6,*) 'NetCDF error: ',trim(nf90_strerror(status))
    stop "Stopped"
  end if
 end subroutine check_error

end program read_netcdf
