% Example for creating a netcdf file
% in Matlab and Octave

% create some variables to store them in a netcdf file

latitude = -90:1:90;
longitude = -179:1:180;
[y,x] = meshgrid(pi/180 * latitude,pi/180 * longitude);
temp = cos(2*x) .* cos(y);

%---------------------------------------%
%                                       %
% write data to a netcdf file           %
%                                       %
%---------------------------------------%


filename = 'example.nc'; 
delete(filename);

% coordinate variable longitude

% create a variable longitude of type double with 
% 360 elements (dimension longitude).

nccreate(filename,'longitude','Dimensions',{'longitude',size(temp,1)},'Format','classic');
ncwriteatt(filename,'longitude','standard_name','longitude');
% define a string attribute of the variable longitude
ncwriteatt(filename,'longitude','units','degree_east');

% coordinate variable latitude

nccreate(filename,'latitude','Dimensions',{'latitude',size(temp,2)});
ncwriteatt(filename,'latitude','standard_name','latitude');
ncwriteatt(filename,'latitude','units','degree_north');

% define variable temp

% create a variable temp of type double of the size 360x181 
% (dimension longitude and latitude).

nccreate(filename,'temp','Dimensions',{'longitude','latitude'});
ncwriteatt(filename,'temp','standard_name','northward_sea_water_velocity');
ncwriteatt(filename,'temp','units','m s-1');
ncwriteatt(filename,'temp','valid_range',[-10 40]);

ncwriteatt(filename,'/','history','netcdf file created by write_netcdf.m');

% store the octave variables longitude, latitude
% and temp in the netcdf file

ncwrite(filename,'longitude',longitude);
ncwrite(filename,'latitude',latitude);
ncwrite(filename,'temp',temp);


disp(['example.nc file created. You might now inspect this file"']);
disp(['with the shell command "ncdump -h example.nc"']);

